# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from .....schema_classes import EntityChangeDetailsClass
from .....schema_classes import EntityChangeTypeClass
from .....schema_classes import SubscriptionInfoClass
from .....schema_classes import SubscriptionNotificationConfigClass
from .....schema_classes import SubscriptionTypeClass


EntityChangeDetails = EntityChangeDetailsClass
EntityChangeType = EntityChangeTypeClass
SubscriptionInfo = SubscriptionInfoClass
SubscriptionNotificationConfig = SubscriptionNotificationConfigClass
SubscriptionType = SubscriptionTypeClass

# fmt: on



# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from .....schema_classes import AnomalyInfoClass
from .....schema_classes import AnomalyReviewClass
from .....schema_classes import AnomalyReviewStateClass
from .....schema_classes import AnomalySourceClass
from .....schema_classes import AnomalySourcePropertiesClass
from .....schema_classes import AnomalySourceTypeClass
from .....schema_classes import AnomalyStateClass
from .....schema_classes import AnomalyStatusClass
from .....schema_classes import AnomalyStatusPropertiesClass
from .....schema_classes import AnomalyTypeClass


AnomalyInfo = AnomalyInfoClass
AnomalyReview = AnomalyReviewClass
AnomalyReviewState = AnomalyReviewStateClass
AnomalySource = AnomalySourceClass
AnomalySourceProperties = AnomalySourcePropertiesClass
AnomalySourceType = AnomalySourceTypeClass
AnomalyState = AnomalyStateClass
AnomalyStatus = AnomalyStatusClass
AnomalyStatusProperties = AnomalyStatusPropertiesClass
AnomalyType = AnomalyTypeClass

# fmt: on



# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from .....schema_classes import ActionRequestArchivedClass
from .....schema_classes import ActionRequestInfoClass
from .....schema_classes import ActionRequestParamsClass
from .....schema_classes import ActionRequestStatusClass
from .....schema_classes import CreateGlossaryNodeProposalClass
from .....schema_classes import CreateGlossaryTermProposalClass
from .....schema_classes import DataContractProposalClass
from .....schema_classes import DataContractProposalOperationTypeClass
from .....schema_classes import DescriptionProposalClass
from .....schema_classes import GlossaryTermProposalClass
from .....schema_classes import TagProposalClass


ActionRequestArchived = ActionRequestArchivedClass
ActionRequestInfo = ActionRequestInfoClass
ActionRequestParams = ActionRequestParamsClass
ActionRequestStatus = ActionRequestStatusClass
CreateGlossaryNodeProposal = CreateGlossaryNodeProposalClass
CreateGlossaryTermProposal = CreateGlossaryTermProposalClass
DataContractProposal = DataContractProposalClass
DataContractProposalOperationType = DataContractProposalOperationTypeClass
DescriptionProposal = DescriptionProposalClass
GlossaryTermProposal = GlossaryTermProposalClass
TagProposal = TagProposalClass

# fmt: on



# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from .....schema_classes import AssertionEvaluationParametersClass
from .....schema_classes import AssertionEvaluationParametersTypeClass
from .....schema_classes import AssertionEvaluationSpecClass
from .....schema_classes import AssertionMonitorClass
from .....schema_classes import AuditLogSpecClass
from .....schema_classes import DataHubOperationSpecClass
from .....schema_classes import DatasetFieldAssertionParametersClass
from .....schema_classes import DatasetFieldAssertionSourceTypeClass
from .....schema_classes import DatasetFreshnessAssertionParametersClass
from .....schema_classes import DatasetFreshnessSourceTypeClass
from .....schema_classes import DatasetVolumeAssertionParametersClass
from .....schema_classes import DatasetVolumeSourceTypeClass
from .....schema_classes import MonitorInfoClass
from .....schema_classes import MonitorModeClass
from .....schema_classes import MonitorStatusClass
from .....schema_classes import MonitorTimeseriesStateClass
from .....schema_classes import MonitorTypeClass


AssertionEvaluationParameters = AssertionEvaluationParametersClass
AssertionEvaluationParametersType = AssertionEvaluationParametersTypeClass
AssertionEvaluationSpec = AssertionEvaluationSpecClass
AssertionMonitor = AssertionMonitorClass
AuditLogSpec = AuditLogSpecClass
DataHubOperationSpec = DataHubOperationSpecClass
DatasetFieldAssertionParameters = DatasetFieldAssertionParametersClass
DatasetFieldAssertionSourceType = DatasetFieldAssertionSourceTypeClass
DatasetFreshnessAssertionParameters = DatasetFreshnessAssertionParametersClass
DatasetFreshnessSourceType = DatasetFreshnessSourceTypeClass
DatasetVolumeAssertionParameters = DatasetVolumeAssertionParametersClass
DatasetVolumeSourceType = DatasetVolumeSourceTypeClass
MonitorInfo = MonitorInfoClass
MonitorMode = MonitorModeClass
MonitorStatus = MonitorStatusClass
MonitorTimeseriesState = MonitorTimeseriesStateClass
MonitorType = MonitorTypeClass

# fmt: on



# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from ......schema_classes import ActionRequestKeyClass
from ......schema_classes import AnomalyKeyClass
from ......schema_classes import AssertionKeyClass
from ......schema_classes import ChartKeyClass
from ......schema_classes import ConstraintKeyClass
from ......schema_classes import ContainerKeyClass
from ......schema_classes import CorpGroupKeyClass
from ......schema_classes import CorpUserKeyClass
from ......schema_classes import DashboardKeyClass
from ......schema_classes import DataContractKeyClass
from ......schema_classes import DataFlowKeyClass
from ......schema_classes import DataHubAccessTokenKeyClass
from ......schema_classes import DataHubConnectionKeyClass
from ......schema_classes import DataHubIngestionSourceKeyClass
from ......schema_classes import DataHubPolicyKeyClass
from ......schema_classes import DataHubRetentionKeyClass
from ......schema_classes import DataHubRoleKeyClass
from ......schema_classes import DataHubSecretKeyClass
from ......schema_classes import DataHubStepStateKeyClass
from ......schema_classes import DataHubUpgradeKeyClass
from ......schema_classes import DataHubViewKeyClass
from ......schema_classes import DataJobKeyClass
from ......schema_classes import DataPlatformInstanceKeyClass
from ......schema_classes import DataPlatformKeyClass
from ......schema_classes import DataProcessInstanceKeyClass
from ......schema_classes import DataProcessKeyClass
from ......schema_classes import DatasetKeyClass
from ......schema_classes import DomainKeyClass
from ......schema_classes import ExecutionRequestKeyClass
from ......schema_classes import GlobalSettingsKeyClass
from ......schema_classes import GlossaryNodeKeyClass
from ......schema_classes import GlossaryTermKeyClass
from ......schema_classes import IncidentKeyClass
from ......schema_classes import InviteTokenKeyClass
from ......schema_classes import LinkPreviewKeyClass
from ......schema_classes import MLFeatureKeyClass
from ......schema_classes import MLFeatureTableKeyClass
from ......schema_classes import MLModelDeploymentKeyClass
from ......schema_classes import MLModelGroupKeyClass
from ......schema_classes import MLModelKeyClass
from ......schema_classes import MLPrimaryKeyKeyClass
from ......schema_classes import MonitorKeyClass
from ......schema_classes import NotebookKeyClass
from ......schema_classes import OwnershipTypeKeyClass
from ......schema_classes import PostKeyClass
from ......schema_classes import QueryKeyClass
from ......schema_classes import RecommendationModuleKeyClass
from ......schema_classes import RoleKeyClass
from ......schema_classes import SchemaFieldKeyClass
from ......schema_classes import SubscriptionKeyClass
from ......schema_classes import TagKeyClass
from ......schema_classes import TelemetryKeyClass
from ......schema_classes import TestKeyClass


ActionRequestKey = ActionRequestKeyClass
AnomalyKey = AnomalyKeyClass
AssertionKey = AssertionKeyClass
ChartKey = ChartKeyClass
ConstraintKey = ConstraintKeyClass
ContainerKey = ContainerKeyClass
CorpGroupKey = CorpGroupKeyClass
CorpUserKey = CorpUserKeyClass
DashboardKey = DashboardKeyClass
DataContractKey = DataContractKeyClass
DataFlowKey = DataFlowKeyClass
DataHubAccessTokenKey = DataHubAccessTokenKeyClass
DataHubConnectionKey = DataHubConnectionKeyClass
DataHubIngestionSourceKey = DataHubIngestionSourceKeyClass
DataHubPolicyKey = DataHubPolicyKeyClass
DataHubRetentionKey = DataHubRetentionKeyClass
DataHubRoleKey = DataHubRoleKeyClass
DataHubSecretKey = DataHubSecretKeyClass
DataHubStepStateKey = DataHubStepStateKeyClass
DataHubUpgradeKey = DataHubUpgradeKeyClass
DataHubViewKey = DataHubViewKeyClass
DataJobKey = DataJobKeyClass
DataPlatformInstanceKey = DataPlatformInstanceKeyClass
DataPlatformKey = DataPlatformKeyClass
DataProcessInstanceKey = DataProcessInstanceKeyClass
DataProcessKey = DataProcessKeyClass
DatasetKey = DatasetKeyClass
DomainKey = DomainKeyClass
ExecutionRequestKey = ExecutionRequestKeyClass
GlobalSettingsKey = GlobalSettingsKeyClass
GlossaryNodeKey = GlossaryNodeKeyClass
GlossaryTermKey = GlossaryTermKeyClass
IncidentKey = IncidentKeyClass
InviteTokenKey = InviteTokenKeyClass
LinkPreviewKey = LinkPreviewKeyClass
MLFeatureKey = MLFeatureKeyClass
MLFeatureTableKey = MLFeatureTableKeyClass
MLModelDeploymentKey = MLModelDeploymentKeyClass
MLModelGroupKey = MLModelGroupKeyClass
MLModelKey = MLModelKeyClass
MLPrimaryKeyKey = MLPrimaryKeyKeyClass
MonitorKey = MonitorKeyClass
NotebookKey = NotebookKeyClass
OwnershipTypeKey = OwnershipTypeKeyClass
PostKey = PostKeyClass
QueryKey = QueryKeyClass
RecommendationModuleKey = RecommendationModuleKeyClass
RoleKey = RoleKeyClass
SchemaFieldKey = SchemaFieldKeyClass
SubscriptionKey = SubscriptionKeyClass
TagKey = TagKeyClass
TelemetryKey = TelemetryKeyClass
TestKey = TestKeyClass

# fmt: on



# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from .......schema_classes import CostCurrencyCodeClass
from .......schema_classes import CostFeaturesClass
from .......schema_classes import StorageFeaturesClass
from .......schema_classes import UsageFeaturesClass


CostCurrencyCode = CostCurrencyCodeClass
CostFeatures = CostFeaturesClass
StorageFeatures = StorageFeaturesClass
UsageFeatures = UsageFeaturesClass

# fmt: on



# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from .....schema_classes import ChartCellClass
from .....schema_classes import EditableNotebookPropertiesClass
from .....schema_classes import NotebookCellClass
from .....schema_classes import NotebookCellTypeClass
from .....schema_classes import NotebookContentClass
from .....schema_classes import NotebookInfoClass
from .....schema_classes import QueryCellClass
from .....schema_classes import TextCellClass


ChartCell = ChartCellClass
EditableNotebookProperties = EditableNotebookPropertiesClass
NotebookCell = NotebookCellClass
NotebookCellType = NotebookCellTypeClass
NotebookContent = NotebookContentClass
NotebookInfo = NotebookInfoClass
QueryCell = QueryCellClass
TextCell = TextCellClass

# fmt: on



# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
from .....schema_classes import ArrayTypeClass
from .....schema_classes import BinaryJsonSchemaClass
from .....schema_classes import BooleanTypeClass
from .....schema_classes import BytesTypeClass
from .....schema_classes import DatasetFieldForeignKeyClass
from .....schema_classes import DateTypeClass
from .....schema_classes import EditableSchemaFieldInfoClass
from .....schema_classes import EditableSchemaMetadataClass
from .....schema_classes import EnumTypeClass
from .....schema_classes import EspressoSchemaClass
from .....schema_classes import FixedTypeClass
from .....schema_classes import ForeignKeyConstraintClass
from .....schema_classes import ForeignKeySpecClass
from .....schema_classes import KafkaSchemaClass
from .....schema_classes import KeyValueSchemaClass
from .....schema_classes import MapTypeClass
from .....schema_classes import MySqlDDLClass
from .....schema_classes import NullTypeClass
from .....schema_classes import NumberTypeClass
from .....schema_classes import OracleDDLClass
from .....schema_classes import OrcSchemaClass
from .....schema_classes import OtherSchemaClass
from .....schema_classes import PrestoDDLClass
from .....schema_classes import RecordTypeClass
from .....schema_classes import SchemaFieldClass
from .....schema_classes import SchemaFieldDataTypeClass
from .....schema_classes import SchemaFieldSpecClass
from .....schema_classes import SchemaMetadataClass
from .....schema_classes import SchemaProposalClass
from .....schema_classes import SchemaProposalsClass
from .....schema_classes import SchemalessClass
from .....schema_classes import StringTypeClass
from .....schema_classes import TimeTypeClass
from .....schema_classes import UnionTypeClass
from .....schema_classes import UrnForeignKeyClass


ArrayType = ArrayTypeClass
BinaryJsonSchema = BinaryJsonSchemaClass
BooleanType = BooleanTypeClass
BytesType = BytesTypeClass
DatasetFieldForeignKey = DatasetFieldForeignKeyClass
DateType = DateTypeClass
EditableSchemaFieldInfo = EditableSchemaFieldInfoClass
EditableSchemaMetadata = EditableSchemaMetadataClass
EnumType = EnumTypeClass
EspressoSchema = EspressoSchemaClass
FixedType = FixedTypeClass
ForeignKeyConstraint = ForeignKeyConstraintClass
ForeignKeySpec = ForeignKeySpecClass
KafkaSchema = KafkaSchemaClass
KeyValueSchema = KeyValueSchemaClass
MapType = MapTypeClass
MySqlDDL = MySqlDDLClass
NullType = NullTypeClass
NumberType = NumberTypeClass
OracleDDL = OracleDDLClass
OrcSchema = OrcSchemaClass
OtherSchema = OtherSchemaClass
PrestoDDL = PrestoDDLClass
RecordType = RecordTypeClass
SchemaField = SchemaFieldClass
SchemaFieldDataType = SchemaFieldDataTypeClass
SchemaFieldSpec = SchemaFieldSpecClass
SchemaMetadata = SchemaMetadataClass
SchemaProposal = SchemaProposalClass
SchemaProposals = SchemaProposalsClass
Schemaless = SchemalessClass
StringType = StringTypeClass
TimeType = TimeTypeClass
UnionType = UnionTypeClass
UrnForeignKey = UrnForeignKeyClass

# fmt: on



# Autogenerated by datahub's custom_package_codegen.py
# DO NOT EDIT THIS FILE DIRECTLY

from setuptools import setup

_package_name = "acryl-datahub-cloud"
_package_version = "0.2.13.4"

setup(
    name=_package_name,
    version=_package_version,
    install_requires=[
        "avro-gen3==0.7.11",
        "acryl-datahub",
    ],
    entry_points={
        "datahub.custom_packages": [
            "models=acryl_datahub_cloud.models.schema_classes",
        ],
    },
)
